<?php

namespace Drupal\filter_term\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Render\Markup;
use Drupal\user\Entity\User;

/**
 * Default controller for the filter_term module.
 */
class DefaultController extends ControllerBase {

  /**
   * Function to get nid from list of tid.
   */
  public function content() {
    $base_path = \Drupal::request()->getBaseUrl();

    $form = \Drupal::formBuilder()->getForm('\Drupal\filter_term\Form\VocabForm');
    
    $title = \Drupal::request()->query->get('title');
    $content_type = \Drupal::request()->query->get('content_type');
    $vocabulary = \Drupal::request()->query->get('vocabulary');
    $term_data = \Drupal::request()->query->get('term');
    $user_id = \Drupal::request()->query->get('users');
    if(!empty($user_id)) {
      $user = User::load($user_id);
      $user_name = $user->get('name')->value;
    }
    
    if (!empty($vocabulary) and  empty($term_data) and empty($content_type)) {
      $query = \Drupal::database()->select('taxonomy_index', 'ti');
      $query->join('node_field_data', 'nfd', 'nfd.nid = ti.nid');
      $query->join('users_field_data', 'u', 'n.uid=u.uid');
      $query->fields('u', ['uid', 'name']);
      $query->fields('ti', ['nid','type','title','status']);
      $query->condition('ti.tid', $term_data);
      // Add the condition on the content type, if content type is set.
      if (isset($content_type) && !empty($content_type)) {
        $query->condition('nfd.type', $content_type);
      }
      if(!empty($title)) {
        $query->condition('title', $title, '=');
      }
      if(!empty($user_name)) {
        $query->condition('u.name', $user_name, '=');
      }

      $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(2);
      $result = $pager->execute()->fetchAll();
    }
    elseif(!empty($vocabulary && $term_data)) {
      $query = \Drupal::database()->select('taxonomy_index', 'ti');
      $query->join('node_field_data', 'nfd', 'nfd.nid = ti.nid');
      $query->join('users_field_data', 'u', 'nfd.uid=u.uid');
      $query->fields('nfd', ['nid','type','title','status']);
      $query->fields('u', ['uid', 'name']);
      $query->condition('ti.tid', $term_data);
      // Add the condition on the content type, if content type is set.
      if (isset($content_type) && !empty($content_type)) {
        $query->condition('nfd.type', $content_type);
      }
      if(!empty($title)) {
        $query->condition('title', $title, '=');
      }
      if(!empty($user_name)) {
          $query->condition('u.name', $user_name, '=');
      }
      //For the pagination we need to extend the pagerselectextender and
      $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(2);
      $result = $pager->execute()->fetchAll();
      
    }
    else{
      $query = \Drupal::database()->select('node_field_data', 'nfd');
      $query->join('users_field_data', 'u', 'nfd.uid=u.uid');
      $query->fields('nfd', ['nid','type','title','status']);
      $query->fields('u', ['uid', 'name']);
      if (isset($content_type) && !empty($content_type)) {
        $query->condition('nfd.type', $content_type);
      }
      if(!empty($title)) {
        $query->condition('title', $title, '=');
      }
      if(!empty($user_name)) {
        $query->condition('u.name', $user_name, '=');
      }
      //For the pagination we need to extend the pagerselectextender and
      $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(2);
      $result = $pager->execute()->fetchAll();
    }
    $data = [];
    foreach ($result as $value){
      $url = new FormattableMarkup('<a href=":link">:label</a>', [
        ':link' => Url::fromRoute('entity.node.edit_form', ['node' => $value->nid])->toString(),
        ':label' => 'Edit',
      ]);
      $operation = $this->t('@editlink',
      ['@editlink' => $url]);
      $data[] = [
        'title' => Markup::create('<a href="'. $base_path .'/node/'. $value->nid .'">'.  $value->title .'</a>'),
        'type' => $value->type,
        'author' => Markup::create('<a href="'. $base_path .'/node/'.  $value->uid .'">' . $value->name . '</a>'),
        'status' => $value->status == 1 ? 'Published': 'Unpublished',
        'edit' => $operation,
      ];
      // dump($data);exit;
    }
    $header = [
      ['data' => $this->t('Title'), 'field' => 'title'],
      ['data' => $this->t('Content type'), 'field' => 'type'],
      ['data' => $this->t('Author'), 'field' => 'author'],
      ['data' => $this->t('Status'), 'field' => 'status'],
      ['data' => $this->t('Operations')],   
    ];

    $form['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $data,
      '#empty' => $this->t('No Data found'),
    ];

    // Finally add the pager.
    $form['pager'] = [
      '#type' => 'pager'
    ];
    return $form;
  }
}