<?php

namespace Drupal\filter_term\Form;

use Drupal\taxonomy\Entity\Vocabulary;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides an term load basis on vocabulary form.
 */
class VocabForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vocab_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $vocabulary = NULL, $term = NULL, $keys = NULL) {

    $vocabulary = \Drupal::request()->query->get('vocabulary');
    $term_data = \Drupal::request()->query->get('term');
    $title = \Drupal::request()->query->get('title');
    $content_type = \Drupal::request()->query->get('content_type');
    $user_role = \Drupal::request()->query->get('users');

    $vocabularies = Vocabulary::loadMultiple();

    $options = [];
    $options = ['-select-'];
    foreach ($vocabularies as $voc) {
      // Get label names of vocabulary.
      $options[$voc->id()] = $voc->label();
    }

    $form['vocabulary'] = [
      '#type' => 'select',
      '#title' => $this->t('Vocabulary'),
      '#options' => $options,
      '#default_value' => !empty($vocabulary) ? $vocabulary : '',
      '#ajax' => [
        'callback' => '::reloadTermCallback',
        'wrapper' => 'term-field-wrapper',
        'event' => 'change',
      ],
    ];

    $vocab_list = $form_state->getValue('vocabulary');
    if (!empty($vocab_list)) {
      $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadTree($vocab_list);
      $term_tree = [];
      $term_tree = ['-select-'];
      foreach ($terms as $term) {
        $term_tree[$term->tid] = $term->name;
      }
    }
    else {
      $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadTree($vocabulary);
      $term_tree = [];
      $term_tree = ['-select-'];
      foreach ($terms as $term) {
        $term_tree[$term->tid] = $term->name;
      }
    }

    $form['term'] = [
      '#type' => 'select',
      '#title' => $this->t('Taxonomy Term'),
      '#options'   => $term_tree,
      '#default_value' => !empty($term_data) ? $term_data : '',
      '#prefix' => '<div id="term-field-wrapper">',
      '#suffix' => '</div>',
    ];

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => !empty($title) ? $title : '',
    ];

    $node_types = NodeType::loadMultiple();
    // If you need to display them in a drop down:
    $options = [];
    $options = ['-select-'];
    foreach ($node_types as $node_type) {
      $options[$node_type->id()] = $node_type->label();
    }

    $form['content_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Content type'),
      '#options' => $options,
      '#default_value' => !empty($content_type) ? $content_type : '',
      '#executes_submit_callback' => TRUE,
    ];

    //Users list in drop down
    $userStorage = \Drupal::entityTypeManager()->getStorage('user');
    $query = $userStorage->getQuery();
    $uids = $query
      ->condition('status', '1')
      ->accessCheck(true)
      ->execute();
    $users = $userStorage->loadMultiple($uids);
    $author_options = [];
    $author_options = ['-select-'];
    foreach($users as $user) {
      // $users[1]->values["name"]["x-default"]
      $name = $user->get('name')->value;
      // $roles = $user->getRoles();
      $author_options[] = $name;
    }
    $form['roles'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Author'),
      '#default_value' => !empty($user_role) ? $user_role : '',
      '#options' => $author_options,
      '#executes_submit_callback' => true,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];

    $form['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset'),
      '#submit' => ['::resetForm'],
    ];
    $form['#attached']['library'][] = 'filter_term/filter_term_styles';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function reloadTermCallback(array &$form, FormStateInterface $form_state) {
    return $form['term'];
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $title = $form_state->getValue('title');
    $content_type = $form_state->getValue('content_type');
    $users = $form_state->getValue('roles');
    $term_data = $form_state->getValue('term');
    $vocabulary = $form_state->getValue('vocabulary');
    $url = Url::fromRoute('filter_term.allcontent')->setRouteParameters(['title' => $title, 'content_type' => $content_type, 'users' => $users, 'term' => $term_data, 'vocabulary' => $vocabulary]);
    $form_state->setRedirectUrl($url);
  }

  /**
   * Resets the filter selections.
   */
  public function resetForm(array &$form, FormStateInterface $form_state) {
    $url = Url::fromRoute('filter_term.allcontent');
    $form_state->setRedirectUrl($url);
  }

}
